#ifndef NT2_INCLUDE_FUNCTIONS_PLANEROT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PLANEROT_HPP_INCLUDED

#include <nt2/linalg/include/functions/planerot.hpp>

#endif
